@@ -1,4 +1,5 @@
 import argparse
+from typing import Optional
 
 import annofabcli
 import annofabcli.common.cli
@@ -16,13 +17,13 @@ def parse_args(parser: argparse.ArgumentParser):
     # サブコマンドの定義
 
     annofabcli.job.delete_job.add_parser(subparsers)
-    annofabcli.job.list_generated_task_history.add_parser(subparsers)
     annofabcli.job.list_job.add_parser(subparsers)
     annofabcli.job.list_last_job.add_parser(subparsers)
+    annofabcli.job.list_generated_task_history.add_parser(subparsers)
     annofabcli.job.wait_job.add_parser(subparsers)
 
 
-def add_parser(subparsers: argparse._SubParsersAction):
+def add_parser(subparsers: Optional[argparse._SubParsersAction] = None):
     subcommand_name = "job"
     subcommand_help = "ジョブ関係のサブコマンド"
     description = "ジョブ関係のサブコマンド"
@@ -31,3 +32,4 @@ def add_parser(subparsers: argparse._SubParsersAction):
         subparsers, subcommand_name, subcommand_help, description, is_subcommand=False
     )
     parse_args(parser)
+    return parser
