@@ -104,7 +104,7 @@ class Database:
         self.logging_prefix = f"project_id={project_id}"
 
     @staticmethod
-    def task_exists(task_list: List[Task], task_id) -> bool:
+    def task_exists(task_list: List[Task], task_id: str) -> bool:
         task = more_itertools.first_true(task_list, pred=lambda e: e["task_id"] == task_id)
         if task is None:
             return False
@@ -112,7 +112,7 @@ class Database:
             return True
 
     def get_annotation_count_by_task(self) -> Dict[str, int]:
-        logger.debug(f"{self.logging_prefix}: reading {str(self.annotations_zip_path)}")
+        logger.debug(f"{self.logging_prefix}: reading '{str(self.annotations_zip_path)}'")
 
         result: Dict[str, int] = defaultdict(int)
         for index, parser in enumerate(lazy_parse_simple_annotation_zip(self.annotations_zip_path)):
@@ -127,7 +127,7 @@ class Database:
         return result
 
     def read_inspections_from_json(self, task_id_list: List[str]) -> Dict[str, Dict[InputDataId, List[Inspection]]]:
-        logger.debug(f"{self.logging_prefix}: reading {self.inspection_json_path}")
+        logger.debug(f"{self.logging_prefix}: reading '{self.inspection_json_path}'")
 
         with open(str(self.inspection_json_path), encoding="utf-8") as f:
             all_inspections = json.load(f)
@@ -154,7 +154,7 @@ class Database:
 
     def read_input_data_from_json(self) -> Dict[str, PseudoInputData]:
         path = self.input_data_json_path
-        logger.debug(f"{self.logging_prefix}: reading {path}")
+        logger.debug(f"{self.logging_prefix}: reading '{path}'")
         with open(str(path), encoding="utf-8") as f:
             all_input_data_list = json.load(f)
 
@@ -165,7 +165,7 @@ class Database:
         return all_input_data_dict
 
     def read_task_histories_from_json(self, task_id_list: Optional[List[str]] = None) -> Dict[str, List[TaskHistory]]:
-        logger.debug(f"{self.logging_prefix}: reading {self.task_histories_json_path}")
+        logger.debug(f"{self.logging_prefix}: reading '{self.task_histories_json_path}'")
         with open(str(self.task_histories_json_path), encoding="utf-8") as f:
             task_histories_dict = json.load(f)
 
@@ -462,7 +462,7 @@ class Database:
 
             return flag
 
-        logger.debug(f"{self.logging_prefix}: reading {self.tasks_json_path}")
+        logger.debug(f"{self.logging_prefix}: reading '{self.tasks_json_path}'")
         with open(str(self.tasks_json_path), encoding="utf-8") as f:
             all_tasks = json.load(f)
 
